@@ -1,18 +1,7 @@
 /*
- * Copyright 2016 ROSA
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2016 ROSA
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef USBDEVICE_H
 #define USBDEVICE_H
@@ -40,8 +29,8 @@ public:
     // Formats the device description for GUI
     // The format is: "<volume(s)> - <user-friendly name> (<size in megabytes>)"
     QString formatDisplayName() const {
-        return ((m_Volumes.size() == 0) ? i18n("<unmounted>")
-                : m_Volumes.join(", ")) + " - " + m_VisibleName + " (" + KFormat().formatByteSize(m_Size) + ")";
+        return ((m_Volumes.isEmpty()) ? i18n("<unmounted>")
+                : m_Volumes.join(", ")) + " - " + m_VisibleName + " (" + KFormat().formatByteSize(m_Size) + QLatin1Char(')');
     }
 
     // User-friendly name of the device
